@@ -3,7 +3,7 @@ BEGIN {
   $Benchmark::Perl::Formance::Analyzer::Tapper::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Benchmark::Perl::Formance - analyze results using Tapper backend store
-$Benchmark::Perl::Formance::Analyzer::Tapper::VERSION = '0.004';
+$Benchmark::Perl::Formance::Analyzer::Tapper::VERSION = '0.005';
 use 5.010;
 
 use Moose;
@@ -15,7 +15,6 @@ use version 0.77;
 use Data::Structure::Util 'unbless';
 use File::ShareDir 'dist_dir';
 use BenchmarkAnything::Storage::Frontend::Lib;
-use BenchmarkAnything::Evaluations;
 use Template;
 use JSON 'decode_json';
 
@@ -32,7 +31,6 @@ has 'blacklist'  => ( is => 'rw', isa => 'Str',      documentation => "metrics t
 has 'dropnull'   => ( is => 'rw', isa => 'Bool',     documentation => "Drop metrics with null values", default => 0 );
 has 'query'      => ( is => 'rw', isa => 'Str',      documentation => "Search query file or '-' for STDIN", default => "-" );
 has 'balib'      => ( is => 'rw',                    documentation => "where to search for benchmark results", default => sub { BenchmarkAnything::Storage::Frontend::Lib->new } );
-has 'evaluations'=> ( is => 'rw',                    documentation => "where to search for benchmark results", default => sub { BenchmarkAnything::Evaluations->new } );
 has 'template'   => ( is => 'rw', isa => 'Str',
                       documentation => 'output template file',
                       default => 'google-chart-area.tt',
@@ -135,6 +133,7 @@ sub run
 
         require File::Find::Rule;
         require File::Basename;
+        require BenchmarkAnything::Evaluations;
 
         say STDERR sprintf("Perl::Formance - chart rendering: ".~~gmtime."\n") if $self->verbose;
 
@@ -159,7 +158,7 @@ sub run
                                          verbose     => $self->verbose,
                                          debug       => $self->debug,
                                         };
-                my $result_matrix = $self->evaluations->transform_chartlines($chartlines, $transform_options);
+                my $result_matrix = BenchmarkAnything::Evaluations::transform_chartlines($chartlines, $transform_options);
 
                 my $outfile;
                 if (not $outfile  = $self->outfile)
@@ -192,7 +191,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
